@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.11/apps/dwmspath/dwmspath.cc 8479 $
-// @(#) $Id: dwmspath.cc 8479 2016-05-07 03:32:25Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.12/apps/dwmspath/dwmspath.cc 9859 $
+// @(#) $Id: dwmspath.cc 9859 2017-12-19 09:09:55Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -56,7 +56,7 @@ extern "C" {
 #include "DwmOptArgs.hh"
 #include "DwmSvnTag.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.11/apps/dwmspath/dwmspath.cc 8479 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.12/apps/dwmspath/dwmspath.cc 9859 $");
 
 using namespace std;
 
@@ -109,8 +109,9 @@ static void ReplaceDotDots(string & s)
 static void PrependCwd(string & s)
 {
   char  buf[PATH_MAX];
-  getcwd(buf, PATH_MAX);
-  s = string(buf) + "/" + s;
+  if (getcwd(buf, PATH_MAX) == buf) {
+    s = string(buf) + "/" + s;
+  }
   return;
 }
 
