@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmIO.cc 9232 2017-04-25 06:18:58Z dwm $
+// @(#) $Id: DwmIO.cc 9807 2017-12-06 15:33:25Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2004-2007
 //  All rights reserved.
@@ -57,7 +57,7 @@ extern "C" {
 #include "DwmIO.hh"
 #include "DwmPortability.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.11/src/DwmIO.cc 9232 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.12/src/DwmIO.cc 9807 $");
 
 namespace Dwm {
 
@@ -775,11 +775,17 @@ namespace Dwm {
       if (Read(fd,len) == sizeof(len)) {
         rc = sizeof(len);
         if (len > 0) {
-          char  *buf = (char *)calloc(1,len);
-          ssize_t  bytesRead = Read(fd, buf, len);
-          if (bytesRead == len) {
-            rc += len;
-            s.assign(buf, len);
+          char  *buf = (char *)calloc(1, len);
+          if (buf) {
+            ssize_t  bytesRead = Read(fd, buf, len);
+            if (bytesRead == len) {
+              rc += len;
+              s.assign(buf, len);
+            }
+            else {
+              rc = -1;
+            }
+            free(buf);
           }
           else {
             rc = -1;
