@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmLocalInterfaces.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $Id: DwmLocalInterfaces.cc 9858 2017-12-19 03:43:26Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2005-2007
 //  All rights reserved.
@@ -47,6 +47,8 @@ extern "C" {
 
 #if (defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__APPLE__))
     #include <ifaddrs.h>
+    #include <net/if_dl.h>
+    #include <net/ethernet.h>
   #else
     #ifdef __linux__
       #include <linux/sockios.h>
@@ -69,7 +71,7 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmLocalInterfaces.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.11/src/DwmLocalInterfaces.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.12/src/DwmLocalInterfaces.cc 9858 $");
 
 using namespace std;
 
